@@ -119,6 +119,10 @@ splot_draw_to_pixmap0_unbinned (splotd *sp, gboolean draw_hidden, ggobid *gg)
   GGobiExtendedSPlotClass *klass = NULL;
   GGobiExtendedDisplayClass *displayKlass = NULL;
 
+  gint width, height;
+  
+  gdk_drawable_get_size(sp->pixmap0, &width, &height);
+  
   g_assert (d->hidden.nels == d->nrows);
 
   /*
@@ -203,7 +207,10 @@ splot_draw_to_pixmap0_unbinned (splotd *sp, gboolean draw_hidden, ggobid *gg)
       }
 #endif
     } else {  /*-- un-hidden points --*/
-
+      GdkColor unset = { 0, }, set = { 1, }; 
+      GdkBitmap *bitmap = gdk_pixmap_new(NULL, width, height, 1);
+      GdkGC *gc = gdk_gc_new(bitmap);
+      gdk_gc_set_stipple(gg->plot_GC, bitmap);
       maxcolorid = datad_colors_used_get (&ncolors_used, colors_used, d, gg);
       splot_check_colors (maxcolorid, &ncolors_used, colors_used, d, gg);
       /*
@@ -211,8 +218,15 @@ splot_draw_to_pixmap0_unbinned (splotd *sp, gboolean draw_hidden, ggobid *gg)
        * color.  This avoids the need to reset the foreground so often.
       */
       for (k=0; k<ncolors_used; k++) {
+        gdk_gc_set_function(gc, GDK_AND);
+        gdk_gc_set_foreground(gc, &unset);
+        gdk_draw_rectangle(bitmap, gc, TRUE, 0, 0, width, height);
+        gdk_gc_set_function(gc, GDK_OR);
+        gdk_gc_set_foreground(gc, &set);
+        
         current_color = colors_used[k];
         gdk_gc_set_foreground (gg->plot_GC, &scheme->rgb[current_color]);
+        
 #ifdef WIN32
         win32_draw_to_pixmap_unbinned (current_color, sp, draw_hidden, gg);
 #else
@@ -229,18 +243,21 @@ splot_draw_to_pixmap0_unbinned (splotd *sp, gboolean draw_hidden, ggobid *gg)
              * but not the points.
             */
             if (display->options.points_show_p)
-              draw_glyph (sp->pixmap0, &d->glyph_now.els[m], sp->screen,
-                m, gg);
+              blit_glyph (bitmap, gc, &d->glyph_now.els[m], sp->screen, m, gg);
 
             if (klass && klass->within_draw_to_unbinned) {
-              klass->within_draw_to_unbinned(sp, m, 
-              sp->pixmap0, gg->plot_GC);
+              klass->within_draw_to_unbinned(sp, m, sp->pixmap0, gg->plot_GC);
             }
 
           }
         }
+        gdk_gc_set_fill(gg->plot_GC, GDK_STIPPLED);
+        gdk_draw_rectangle(sp->pixmap0, gg->plot_GC, TRUE, 0, 0, width, height);
+        gdk_gc_set_fill(gg->plot_GC, GDK_SOLID);
 #endif
       }
+      g_object_unref(G_OBJECT(gc));
+      g_object_unref(G_OBJECT(bitmap));
     }
   }
 
@@ -818,8 +835,7 @@ splot_pixmap_to_window (splotd *sp, GdkPixmap *pixmap, ggobid *gg) {
 /*------------------------------------------------------------------------*/
 
 void
-splot_redraw (splotd *sp, RedrawStyle redraw_style, ggobid *gg) {
-  RedrawStyle style;
+splot_redraw (splotd *sp, RedrawStyle style, ggobid *gg) {
 
   /*-- sometimes the first draw happens before configure is called --*/
   if (sp == NULL || sp->da == NULL || sp->pixmap0 == NULL) {
@@ -829,12 +845,10 @@ splot_redraw (splotd *sp, RedrawStyle redraw_style, ggobid *gg) {
   /*
    * Event compression is, I think, causing only the last redraw event
    * to get through, so that a full redraw can be blocked by a
-   * subsequent expose.  Can I set a flag when a full redraw is
-   * needed, and then override the setting here?  Or maybe this simple
-   * act will do it:
+   * subsequent expose. 
+   *
+   * Fixed by turning off expose event handlers during tour idle procs.
   */
-  style = MAX(sp->redraw_style, redraw_style);
-
   switch (style) {
     case FULL:  /*-- FULL_2PIXMAP --*/
       splot_clear_pixmap0 (sp, gg);
