@@ -23,6 +23,7 @@
 #include "vars.h"
 #include "externs.h"
 
+#include "ggobi-renderer-factory.h"
 
 /*--------------------------------------------------------------------*/
 /*                             Events                                 */
@@ -35,6 +36,8 @@ splot_configure_cb (GtkWidget *w, GdkEventConfigure *event, splotd *sp)
   displayd *display = (displayd *) sp->displayptr; 
   cpaneld *cpanel = &display->cpanel;
   GGobiData *d = display->d;
+  GGobiRendererFactory *factory = ggobi_renderer_factory_new();
+  GGobiRenderer *renderer; 
 
   /*
    * Somehow when a new splot is added to a table, the initial
@@ -66,6 +69,13 @@ splot_configure_cb (GtkWidget *w, GdkEventConfigure *event, splotd *sp)
   sp->pixmap1 = gdk_pixmap_new (w->window,
     w->allocation.width, w->allocation.height, -1);
 
+/*
+  renderer = ggobi_renderer_factory_create(factory, w->window);
+  sp->pixmap0 = GDK_DRAWABLE(renderer);
+  renderer = ggobi_renderer_factory_create(factory, w->window);
+  sp->pixmap1 = GDK_DRAWABLE(renderer);*/
+  g_object_unref(G_OBJECT(factory));
+  
   if (cpanel->imode == BRUSH) {
     sp->brush_pos.x1 = (gint) ((gfloat) sp->brush_pos.x1 *
       (gfloat) (w->allocation.width) / (gfloat) (sp->max.x));
@@ -119,6 +129,17 @@ splot_expose_cb (GtkWidget *w, GdkEventExpose *event, splotd *sp)
   return retval;
 }
 
+void
+splot_connect_expose_handler (gboolean idled, splotd *sp) 
+{
+  if (idled)  // if idle_proc running
+    g_signal_handlers_disconnect_by_func (G_OBJECT (sp->da),
+       G_CALLBACK(splot_expose_cb), GTK_OBJECT (sp));
+  else
+    g_signal_connect (G_OBJECT (sp->da),
+      "expose_event", G_CALLBACK(splot_expose_cb), (gpointer) sp);
+}
+
 /*-- this will be called by a key_press_cb for each scatterplot mode --*/
 gboolean
 splot_event_handled (GtkWidget *w, GdkEventKey *event,
